diff -urN astra.orig/modules/mpegts/channel.c astra/modules/mpegts/channel.c
--- astra.orig/modules/mpegts/channel.c	2014-07-22 17:46:49.000000000 +0400
+++ astra/modules/mpegts/channel.c	2014-07-22 18:33:22.000000000 +0400
@@ -56,6 +56,7 @@
         const char *name;
         int pnr;
         int set_pnr;
+        int fake_pcr;
         bool sdt;
         bool eit;
         bool cas;
@@ -89,6 +90,7 @@
     uint32_t *sdt_checksum_list;
 
     uint8_t eit_cc;
+    uint8_t fake_pcr_cc;
 
     uint8_t pat_version;
 };
@@ -550,6 +552,12 @@
             PMT_SET_PCR(mod->custom_pmt, mod->pid_map[pcr_pid]);
     }
 
+    if (mod->config.fake_pcr)
+    {
+        mod->stream[pcr_pid] = MPEGTS_PACKET_PCR;
+        PMT_SET_PCR(mod->custom_pmt, mod->config.fake_pcr);
+    }
+
     PSI_SET_SIZE(mod->custom_pmt);
     PSI_SET_CRC32(mod->custom_pmt);
     mpegts_psi_demux(mod->custom_pmt, (ts_callback_t)__module_stream_send, &mod->__stream);
@@ -700,6 +708,24 @@
 
     switch(mod->stream[pid])
     {
+        case MPEGTS_PACKET_PCR:
+            if (mod->config.fake_pcr)
+            {
+                if (mpegts_pcr_check(ts))
+                {
+                    memcpy(mod->custom_ts, ts, TS_PACKET_SIZE);
+
+                    mod->fake_pcr_cc++;
+                    if (mod->fake_pcr_cc > 15)
+                        mod->fake_pcr_cc = 0;
+
+                    mod->custom_ts[3] = mod->fake_pcr_cc + (mod->custom_ts[3] & 0xf0);
+
+                    TS_SET_PID(mod->custom_ts, mod->config.fake_pcr);
+                    module_stream_send(mod, mod->custom_ts);
+                }
+            }
+            break;
         case MPEGTS_PACKET_PES:
             break;
         case MPEGTS_PACKET_PAT:
@@ -781,6 +807,7 @@
     if(module_option_number("pnr", &mod->config.pnr))
     {
         module_option_number("set_pnr", &mod->config.set_pnr);
+        module_option_number("fake_pcr", &mod->config.fake_pcr);
 
         module_option_boolean("cas", &mod->config.cas);
 
diff -urN astra.orig/modules/mpegts/mpegts.h astra/modules/mpegts/mpegts.h
--- astra.orig/modules/mpegts/mpegts.h	2014-07-22 17:46:49.000000000 +0400
+++ astra/modules/mpegts/mpegts.h	2014-07-22 18:35:18.000000000 +0400
@@ -98,6 +98,7 @@
     MPEGTS_PACKET_VIDEO     = MPEGTS_PACKET_PES | 0x01,
     MPEGTS_PACKET_AUDIO     = MPEGTS_PACKET_PES | 0x02,
     MPEGTS_PACKET_SUB       = MPEGTS_PACKET_PES | 0x04,
+    MPEGTS_PACKET_PCR       = MPEGTS_PACKET_PES | 0x08,
     MPEGTS_PACKET_DATA      = 0x01000000,
     MPEGTS_PACKET_NULL      = 0x02000000
 } mpegts_packet_type_t;
diff -urN astra.orig/scripts/stream.lua astra/scripts/stream.lua
--- astra.orig/scripts/stream.lua	2014-07-22 17:46:49.000000000 +0400
+++ astra/scripts/stream.lua	2014-07-22 16:45:02.000000000 +0400
@@ -747,6 +747,7 @@
         if input_conf.pnr ~= nil then
             channel_conf.pnr = input_conf.pnr
             if input_conf.set_pnr then channel_conf.set_pnr = input_conf.set_pnr end
+            if input_conf.fake_pcr then channel_conf.fake_pcr = input_conf.fake_pcr end
 
             if input_conf.no_sdt ~= true and _G.no_sdt ~= true then channel_conf.sdt = true end
             if input_conf.no_eit ~= true and _G.no_eit ~= true then channel_conf.eit = true end
